                    <tr>
                      <td colspan="2" class="repeat-container">
                        <table class="repeat-table">
                          <tr>
                            <td>