<tr>
<td colspan="4">        <div></div>
                        <table cellspacing="0" cellpadding="0" width="100%">
                          <tbody>
                            <tr>
                              <td style="border-top: 1px solid black; border-right: 1px solid black; border-left: 1px solid black;" class="odk-table-item-label-cell"></td>
                              {% for field in table[0].input_field %}
                                <td style="border-top: 1px solid black; border-right: 1px solid black;" class="odk-table-response odk-table-response-header">
                                  <span class="label">{{ field.label }}</span> <span class="choice-name">{{ field.name }}</span>
                                </td>
                              {% endfor %}
                            </tr>

                            {% for row in table[1:] %}
                              <tr>
                                <td style="border-top: 1px solid black; border-right: 1px solid black; border-left: 1px solid black;" class=" odk-table-item-label-cell">
                                  <span class="label">{{ row.label }}</span> <span class="choice-name">{{ row.name }}</span>
                                </td>
                                {% for option in row.input_field %}
                                  <td style="border-top: 1px solid black; border-right: 1px solid black;" class="odk-table-response">
                                    {% set select_option = row %}
                                    {% include "content/prompt/inputs/selects.html" %}
                                  </td>
                                {% endfor %}
                              </tr>
                            {% endfor %}
                            
                          </tbody>
                        </table>
</td>
</tr>
