<html>
    <head>
        <title>{{ data.title }}</title>
        <meta http-equiv="content-type" content="text/html; charset=UTF-8">
        {# <link rel="stylesheet" type="text/css" href="styles.css"> #}
        {% include "styles.html" %}
    </head>
    <body id="survey">
        <div id="container">
            <div id="identification_section" class="section">
                <h2 id="survey-heading">{{ data.title }}</h2>
                <table>
                  <tbody>